@@ -40,6 +40,7 @@ void replace_stars(char *fname);
 void back_to_stars(char *aligned, char *ori);
 int save_fasta_file_no_gaponly(char *fname, char **sequence, int tot_seqs, int *each_length, int *sel_seqs);
 void unalign(SEA_VIEW *view);
+int reorder_seqs(int tot, char **seq, char **name);
 
 /* extern proto */
 extern int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const char *label);
@@ -291,6 +292,7 @@ view->cursor_in_comment = FALSE;
 view->cursor_seq = view->first_seq;
 /* lecture de l'alignement multiple produit par clustalw */
 num = read_fasta_align(fname, &seq, &seqname, &comments, &pheader, &err_message, FALSE);
+if( reorder_seqs(num, seq, seqname) ) return TRUE;
 for(i = 0; i < num; i++) free(seqname[i]);
 if(num > 0) { free(seqname); free(comments); }
 if( num != total) {
@@ -557,6 +559,11 @@ if(status) {
 	
 sprintf(tmp, "msa_args_%d", view->alignment_algorithm +  1);
 strcpy(local, get_res_value(tmp, NULL));
+  
+  if(view->alignment_algorithm == 1 && (p = strstr(local, " -stable")) != NULL) {
+    //make sure -stable is not in muscle arguments because it's buggy
+    memmove(p, p+8, strlen(p+8)+1);
+    }
 
 /* add user-entered options to command */
 Fl_Menu_Button *menu_align = (Fl_Menu_Button *)view->menu_align;
@@ -916,12 +923,14 @@ int count = int_res_value("msa_algo_count", 0);
 	set_res_value("msa_name_1", "clustalw"); 
 #endif
 if(count < 2) {
-	set_res_value("msa_algo_count", "2");
-	set_res_value("alignment", "1"); /* muscle is default starting msa method */
-	set_res_value("msa_args_1", "-align -infile=%f.pir -outfile=%f.out -outorder=input -output=fasta");
-	set_res_value("msa_name_2", "muscle"); 
-	set_res_value("msa_args_2", "-in %f.pir -out %f.out -stable");
-	}
+  set_res_value("msa_algo_count", "2");
+  set_res_value("alignment", "1"); /* muscle is default starting msa method */
+//set_res_value("msa_args_1", "-align -infile=%f.pir -outfile=%f.out -outorder=input -output=fasta");
+  set_res_value("msa_args_1", "-align -infile=%f.pir -outfile=%f.out -output=fasta");
+  set_res_value("msa_name_2", "muscle"); 
+//set_res_value("msa_args_2", "-in %f.pir -out %f.out -stable");
+  set_res_value("msa_args_2", "-in %f.pir -out %f.out");
+  }
 }
 
 enum {profile_clustalw2, profile_muscle};
@@ -1275,3 +1284,20 @@ void unalign(SEA_VIEW *view)
 	view->horsli->redraw();
 	set_seaview_modified(view, TRUE);
 }
+
+int reorder_seqs(int tot, char **seq, char **name)
+//reorders sequences in seq in their original order using their names
+//that start with 1_, 2_, 3_, etc...
+//returns TRUE iff memory error
+{
+  int num, rank;
+  char **newseq = (char **)malloc(tot * sizeof(char *));
+  if(newseq == NULL) return TRUE;
+  for( num = 0; num < tot; num++) {
+    sscanf(name[num], "%d", &rank);
+    newseq[rank - 1] = seq[num];
+    }
+  memcpy(seq, newseq, tot * sizeof(char *));
+  free(newseq);
+  return FALSE;
+}
