@@ -1,9 +1,6 @@
 #ifdef __APPLE__
 #include <Carbon/Carbon.h>
 #include "seaview.h"
-#include <string.h>
-#include <stdio.h>
-#include <FL/Fl.H>
 #include <FL/x.H>
 #include <FL/Fl_Sys_Menu_Bar.H>
 #include <FL/Fl_Help_View.H>
@@ -147,18 +144,6 @@ char *MG_GetBundleResourcesDir(void)
 	return fname;
 }
 
-static OSStatus PathToFSSpec(const char *path, FSSpec &spec) {
-    OSStatus err;
-    FSRef ref;
-    if ((err = FSPathMakeRef((const UInt8*)path, &ref, NULL)) != noErr) {
-		return(err);
-    }
-    if ((err = FSGetCatalogInfo(&ref, kFSCatInfoNone, NULL, NULL, &spec,
-								NULL)) != noErr) {
-		return(err);
-    }
-    return(noErr);
-}
 
 static char dialog_start_dir[FL_PATH_MAX]; //shared by MyNavEventProc_Plus & mac_GetOutputFName_Plus
 
@@ -181,10 +166,10 @@ static void MyNavEventProc_Plus (NavEventCallbackMessage callBackSelector,
 			callBackParms->customRect.right = callBackParms->customRect.left + 425;
 	}
 	else if(callBackSelector == kNavCBStart) {
-		FSSpec spec;
-		if(dialog_start_dir[0] != 0 && PathToFSSpec(dialog_start_dir, spec) == noErr) {
+		FSRef fsref;
+		if(dialog_start_dir[0] != 0 && FSPathMakeRef((const UInt8 *)dialog_start_dir, &fsref, NULL) == noErr) {
 			AEDesc desc;
-			err = AECreateDesc(typeFSS, &spec, sizeof(FSSpec), &desc);
+			err = AECreateDesc(typeFSRef, &fsref, sizeof(FSRef), &desc);
 			if(err == noErr)  {
 				NavCustomControl(callBackParms->context, kNavCtlSetLocation, &desc);
 				AEDisposeDesc(&desc);
@@ -1163,59 +1148,4 @@ void draw_rotated_string(const char *txt, int x, int y, float degrees /*clockwis
 	err = ATSUSetLayoutControls (layout, 1, iTag, iSize, aAttr );
 }
 
-/* 
- //the following would copy PDF data to the clipboard using Quartz draw commands
- 
- extern CGContext *fl_gc;
- struct gc_data {
- CGContext *oldflgc;
- CFMutableDataRef data;
- };
- void *MG_PrepareCopy(int w, int h)
- {
- static CGDataConsumerCallbacks callbacks = { MyPutBytes, NULL };
- static struct gc_data retval;
- CGContextRef context;
- CGRect bounds;
- bounds.origin.x = 0;
- bounds.origin.y = 0;
- bounds.size.width = w;
- bounds.size.height = h;
- 
- CFMutableDataRef mydata = CFDataCreateMutable(NULL, 0);
- CGDataConsumerRef myconsumer = CGDataConsumerCreate ((void*) mydata, &callbacks);
- context = CGPDFContextCreate (myconsumer, &bounds, NULL);
- CGDataConsumerRelease (myconsumer);
- if (context == NULL) return NULL;
- retval.oldflgc = fl_gc;
- retval.data = mydata;
- fl_gc = context;
- CGPDFContextBeginPage (fl_gc, NULL);
- CGContextTranslateCTM(fl_gc, 0.5, h-0.5f);
- CGContextScaleCTM(fl_gc, 1.0f, -1.0f);
- return &retval;
- }
- 
- void MG_CompleteCopy(void *mydata)
- {
- struct gc_data *retval = (struct gc_data *)mydata;
- PasteboardRef clipboard = NULL;
- CGPDFContextEndPage (fl_gc);
- CGContextRelease (fl_gc);
- //	 copy PDF to clipboard 
- PasteboardCreate (kPasteboardClipboard, &clipboard);
- PasteboardClear(clipboard);
- (void) PasteboardPutItemFlavor (clipboard, (PasteboardItemID)1, 
- CFSTR("com.adobe.pdf"), // kUTTypePDF
- retval->data, kPasteboardFlavorNoFlags);
- //	CFDataRef bidon = CFDataCreate(NULL, (const UInt8 *)"image", 6);
- //	OSStatus err= PasteboardPutItemFlavor (clipboard, (PasteboardItemID)1, 
- //									CFSTR("public.utf8-plain-text"), 
- //									bidon, kPasteboardFlavorNoFlags); 
- CFRelease (retval->data); 
- CFRelease (clipboard);
- fl_gc = retval->oldflgc;
- }
- */
-
 #endif //__APPLE__
