@@ -1,14 +1,5 @@
 #include <ctype.h>
 #include <time.h>
-#include "FL/Fl.H"
-#include "FL/Fl_Button.H"
-#include "FL/Fl_Box.H"
-#include "FL/Fl_Menu_Button.H"
-#include "FL/Fl_Check_Button.H"
-#include "FL/Fl_Round_Button.H"
-#include "FL/fl_draw.H"
-#include "FL/fl_ask.H"
-#include "FL/Fl_Native_File_Chooser.H"
 #include "unrooted.h"
 #include "treedraw.h"
 
